DartEnumGeneratorOptions class

Implemented types

Constructors

DartEnumGeneratorOptions({String dartTypeName(String validatorName) = toPascalCase, String dartVariantName(String validatorName) = toCamelCase, String insertBeforeEnumVariant(String validatorName) = emptyString, String nameProperty = 'name'})
const

Properties

dartTypeName String Function(String validatorName)
final
dartVariantName String Function(String validatorName)
final
hashCode int
The hash code for this object.
no setterinherited
insertBeforeEnumVariant String Function(String validatorName)
final
nameProperty String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dartTypeFor(EnumValidator validator) String
The Dart type name for the given validator type.
override
getDartTypeGenerator(EnumValidator validator) GeneratorExtras?
Return a Dart type generator for the validator type if necessary.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selfCreateString(EnumValidator validator) String
Returns Dart code that re-creates the Validatable instance or the equivalent Converter instance that can be used to convert properties of the type the validator validates.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited